@@ -3,10 +3,10 @@
 # @package      hubzero-metrics
 # @file         _archive_apache_and_auth_log.sh
 # @author       Swaroop Shivarajapura <swaroop@purdue.edu>
-# @copyright    Copyright (c) 2011-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2011-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2011-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2011-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -43,11 +43,27 @@ fi
 files=$(ls /var/log/apache2/daily/$site-access.log-* 2> /dev/null | wc -l)
 if [ "$files" != "0" ]
 then
+	gzip --quiet /var/log/apache2/daily/$site-access.log-*
 	mv --backup=numbered /var/log/apache2/daily/$site-access.log-* /var/log/apache2/imported/
 fi
 
+files=$(ls /var/log/apache2/daily/new-$site-access.log-* 2> /dev/null | wc -l)
+if [ "$files" != "0" ]
+then
+	gzip --quiet /var/log/apache2/daily/new-$site-access.log-*
+	mv --backup=numbered /var/log/apache2/daily/new-$site-access.log-* /var/log/apache2/imported/
+fi
+
 files=$(ls /var/log/hubzero/daily/cmsauth.log-* 2> /dev/null | wc -l)
 if [ "$files" != "0" ]
 then
+	gzip --quiet /var/log/hubzero/daily/cmsauth.log-*
 	mv --backup=numbered /var/log/hubzero/daily/cmsauth.log-* /var/log/hubzero/imported/
 fi
+
+files=$(ls /var/log/hubzero/daily/cmsdebug.log-* 2> /dev/null | wc -l)
+if [ "$files" != "0" ]
+then
+	gzip --quiet /var/log/hubzero/daily/cmsdebug.log-*
+	mv --backup=numbered /var/log/hubzero/daily/cmsdebug.log-* /var/log/hubzero/imported/
+fi
